import os
from yafowil.base import factory


resourcedir = os.path.join(os.path.dirname(__file__), 'resources')
css = [{
    'group': 'bootstrap',
    'resource': os.path.join('css', 'bootstrap.css'),
    'order': 10,
}, {
    'group': 'bootstrap',
    'resource': os.path.join('css', 'bootstrap-responsive.css'),
    'order': 11,
}]


def register():
    import common
    factory.register_theme('bootstrap', 'yafowil.bootstrap',
                           resourcedir, css=css)


from yafowil.base import factory


factory.theme = 'bootstrap'
factory.defaults['select.label_radio_class'] = 'radio'
factory.defaults['select.label_checkbox_class'] = 'checkbox'

# yafowil.widget.array
factory.defaults['array.table_class'] = 'table table-bordered table-condensed'

# yafowil.widget.dict
factory.defaults['dict.table_class'] = 'dictwidget table table-bordered ' +\
                                       'table-condensed'

# yafowil.widget.datetime
factory.defaults['datetime.datepicker_class'] = 'datepicker input-medium'
factory.defaults['datetime.timepicker_class'] = 'timepicker input-small'

def bs_controls_renderer(widget, data):
    return data.tag('div', data.rendered, class_='controls')

factory.register(
    'bs_controls',
    extractors=[],
    edit_renderers=[bs_controls_renderer],
    display_renderers=[bs_controls_renderer])


def bs_field_class(widget, data):
    if data.errors:
        return 'control-group error'
    return 'control-group'

BOOTSTRAP_MACROS = {
    'form': {
        'chain': 'form',
        'props': {
            'form.class': 'form-horizontal',
        }
    },
    'field': {
        'chain': 'field:label:bs_controls:help:error',
        'props': {
            'field.class': bs_field_class,
            'label.class': 'control-label',
            'label.help': None,
            'error.position': 'after',
            'error.tag': 'span',
            'error.class': 'help-inline',
            'help.position': 'after',
            'help.tag': 'p',
            'help.class': 'help-block',
        }
    },
    'button': {
        'chain': 'submit',
        'props': {
            'submit.class': 'btn',
        }
    },
}

for name, value in BOOTSTRAP_MACROS.items():
    factory.register_macro(name, value['chain'], value['props'])



from setuptools import setup, find_packages
import sys, os

version = '1.0'
shortdesc = 'Bootstrap Styles for YAFOWIL'
longdesc = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()
longdesc += open(os.path.join(os.path.dirname(__file__), 'HISTORY.rst')).read()
longdesc += open(os.path.join(os.path.dirname(__file__), 'LICENSE.rst')).read()
tests_require = ['yafowil[test]']

setup(name='yafowil.bootstrap',
      version=version,
      description=shortdesc,
      long_description=longdesc,
      classifiers=[
            'Environment :: Web Environment',
            'Operating System :: OS Independent',
            'Programming Language :: Python', 
            'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
            'License :: OSI Approved :: BSD License',                    
      ],
      keywords='',
      author='BlueDynamics Alliance',
      author_email='dev@bluedynamics.com',
      url=u'https://github.com/bluedynamics/yafowil.bootstrap',
      license='BSD',
      packages=find_packages('src'),
      package_dir = {'': 'src'},
      namespace_packages=['yafowil'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'yafowil>1.99',
      ],
      tests_require=tests_require,
      extras_require = dict(
          test=tests_require,
      ),
      test_suite="yafowil.bootstrap.tests.test_suite",
      entry_points="""
      [yafowil.plugin]
      register = yafowil.bootstrap:register
      """,
      )
